Re: [cmake-developers] find_package error wording

2012-02-18 Thread Alexander Neundorf
On Friday 17 February 2012, Alexander Neundorf wrote:
 On Friday 17 February 2012, Brad King wrote:
  On 2/17/2012 5:05 PM, Alexander Neundorf wrote:
   I think the nicer MODULE_MODE and CONFIG_MODE keywords are not worth
   breaking backward compatibility of users projects (not cmake) this way.
  
  We can add them and document them in the new version but not mention
  them in error messages for now.
 
 This is what I have so far:
 ---
 policy NEW, Find-module not found:


This is now in the branch FindPackage_MODULE_MODE_Policy on stage.
I still have to add tests.

I wrote documentation for the new CMP0018.
For find_package(), I think the whole first part of the documentation has to 
be modified. Currently it says:
User code should generally look for packages using the above simple 
signature. The remainder of this command documentation specifies the full 
command signature and details of the search process. Project maintainers 
wishing to provide a package to be found by this command are encouraged to 
read on.

I think with this new policy MODULE_MODE should not be considered the simple 
signature and NO_MODULE the full signature anymore, but both with equal 
rights.

Alex
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] Making Config.cmake files easier to write

2012-02-18 Thread Eric Noulard
2012/2/17 Eric Noulard eric.noul...@gmail.com:
 2012/2/17 Alexander Neundorf neund...@kde.org:
 On Friday 17 February 2012, Eric Noulard wrote:
 2012/2/17 Alexander Neundorf neund...@kde.org:
  On Thursday 16 February 2012, Brad King wrote:
  On 2/16/2012 1:24 PM, Alexander Neundorf wrote:
   Actually I expected I would prefer this over the fixed names, but now
   that I've done it and look at what Config.cmake.in file I have to
   write, I think I liked the previous version with the fixed names
   (CONFIG_HELPER) better. I think it was easier to do, a simple scheme.
 
  I think the fixed names are better/simpler too.  I'm not fond of
  CONFIG_HELPER specifically.  The information stored in them is
  about the *package* that the file is configuring, which is why
  I originally proposed the prefix PACKAGE_.  The INCLUDE_INSTALL_DIR
  is where the *package* goes, not where the config helper is/goes.
 
  I pushed a branch MakingConfigFilesEasier_ConfigureMacro to stage.
  It has documentation and a test.
  An example Config.cmake.in file is attached.
  I can still change names etc. tomorrow.
  The macro is in CMakePackageHelpers.cmake.

 Nice piece of work. Should be helpful to many of us.
 Some more tuning remarks.

 Why not offering more bundled interface to this feature ?

 currently you have to:

 1) include(CMakePackageConfigHelpers)
 2) configure_package_config_file(FooConfig.cmake.in
                       ${CMAKE_CURRENT_BINARY_DIR}/FooConfig.cmake
                       INSTALL_DESTINATION ${LIB_INSTALL_DIR}/Foo/cmake
                       PATH_VARS INCLUDE_INSTALL_DIR SYSCONFIG_INSTALL_DIR)
 3) write_basic_package_version_file(
                     ${CMAKE_CURRENT_BINARY_DIR}/FooConfigVersion.cmake
                     VERSION 1.2.3 COMPATIBILITY
                     SameMajorVersion)

 4) install(FILES ${CMAKE_CURRENT_BINARY_DIR}/FooConfig.cmake
              ${CMAKE_CURRENT_BINARY_DIR}/FooConfigVersion.cmake
              DESTINATION ${LIB_INSTALL_DIR}/Foo/cmake )

 Yes, these are all simple orthogonal functions, which can be described with
 one sentence without using and.

 1) is mandatory of course
 3) is optional
 2) and 4) should be using the same INSTALL_DESTINATION  and
 DESTINATION in order to be consistent.

 I cannot imagine doing 2) or 3) without 4).

 You are right.
 It is a somewhat problematic point that the destinations must match.

 So in the end, wouldn't it be simpler (for the user/developer) to have
 something like:

 include(CMakePackageConfigHelpers)
 create_and_install_package_config_files(NAME Foo
                    CONFIG_TEMPLATE FooConfig.cmake.in
                    DESTINATION ${LIB_INSTALL_DIR}/Foo/cmake
                    PATH_VARS INCLUDE_INSTALL_DIR SYSCONFIG_INSTALL_DIR
                    VERSION 1.2.3
                    VERSION_COMPATIBILITY SameMajorVersion)

[...]

 So the point is, is there any usefulness from the CMake user point of view,
 in providing such higher-level (but less powerful) API for CMake
 config file at all.

No obvious sign of interest for this idea on the list.
I won't work on create_and_install_package_config_files and rather continue
my work on improving CPack doc.

May come to that later after Alex's macros has been merged to master.

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] How to cleanly get rid of CMake specific properties?

2012-02-18 Thread Eric Noulard
Hi all,

I'm pursuing my quest for a better CPack doc.
First set of modifications are in master:
 cpack --help-command-xxx
 cpack --help-variable-xxx
works.

However variables are somehow problematic because I get all the
properties defined for CMake in the doc because variables are a
special kind of properties.

CPack (or CTest) is using a instance of cmake object which does:

this-InitializeProperties();

in its constructor
so that I end up with a lot more properties in full doc
i.e. in
cpack --help-full

Than I thought I shall.
Now there is two options:

1) Avoid InitializeProperties(); in cmake object constructor and do
that elsewhere
for CMake and nowhere for CTest and CPack.

2) Let CTest and CPack keep the CMake inherited properties and filter out
the unwaned CMake specific section in the doc.

1) is definitely easier but raise a question:
Do CTest and CPack NEED the cmake property definition?
Is this a wanted behavior or just an oversight?
i.e. is set_property(...) supposed to work in a ctest or cpack
loaded script?

2) is doable but require more work.

in the same way should the standard variable doc section be inherited
from CMake to CTest/CPack?

try (I know it's not supposed to work but nevertheless):
ctest --help-variable-list

and you'll see what I mean.

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] Making Config.cmake files easier to write

2012-02-18 Thread Alexander Neundorf
On Saturday 18 February 2012, Eric Noulard wrote:
...
  include(CMakePackageConfigHelpers)
  create_and_install_package_config_files(NAME Foo
 CONFIG_TEMPLATE FooConfig.cmake.in
 DESTINATION ${LIB_INSTALL_DIR}/Foo/cmake
 PATH_VARS INCLUDE_INSTALL_DIR SYSCONFIG_INSTALL_DIR
 VERSION 1.2.3
 VERSION_COMPATIBILITY SameMajorVersion)
 
 [...]
 
  So the point is, is there any usefulness from the CMake user point of
  view, in providing such higher-level (but less powerful) API for CMake
  config file at all.
 
 No obvious sign of interest for this idea on the list.
 I won't work on create_and_install_package_config_files and rather
 continue my work on improving CPack doc.
 
 May come to that later after Alex's macros has been merged to master.

sign of interest /  ;-)

Alex

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] Some numbers on cmake+ninja+VS on Windows

2012-02-18 Thread Óscar Fuentes
Setup: Windows XP SP3 32 bits running on VMWare Workstation 8.0.1 with 4
real cores (no HT) assigned out of 4 available on the host machine,
which is Kubuntu 11.08 64 bits (kernel version 3.0.0-16-generic).

Visual Studio 2010 Ultimate. JOM 0.9.4 (that's an old version, but on my
experience newer versions are slower).

CMake was taken from https://github.com/syntheticpp/CMake.git, branch
ninja-generator-pr-win revision fa9ce5e, plus this patch:

diff --git a/Modules/Platform/Windows-cl.cmake 
b/Modules/Platform/Windows-cl.cmake
index bc9..be6abb6 100644
--- a/Modules/Platform/Windows-cl.cmake
+++ b/Modules/Platform/Windows-cl.cmake
@@ -37,7 +37,7 @@ SET(CMAKE_COMPILE_RESOURCE rc FLAGS /foOBJECT SOURCE)
 # that is automatically copied into try_compile directories
 # by the global generator.
 SET(MSVC_IDE 1)
-IF(CMAKE_GENERATOR MATCHES Makefiles)
+IF(CMAKE_GENERATOR MATCHES Makefiles OR CMAKE_GENERATOR MATCHES Ninja)
   SET(MSVC_IDE 0)
   IF(NOT CMAKE_VC_COMPILER_TESTS_RUN)
 SET(CMAKE_VC_COMPILER_TESTS 1)
@@ -125,7 +125,7 @@ IF(CMAKE_GENERATOR MATCHES Makefiles)
 ENDIF(CMAKE_COMPILER_RETURN)
 MAKE_DIRECTORY(${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeTmp3)
   ENDIF(NOT CMAKE_VC_COMPILER_TESTS_RUN)
-ENDIF(CMAKE_GENERATOR MATCHES Makefiles)
+ENDIF(CMAKE_GENERATOR MATCHES Makefiles OR CMAKE_GENERATOR MATCHES Ninja)
 
 IF(MSVC_C_ARCHITECTURE_ID MATCHES 64)
   SET(CMAKE_CL_64 1)
diff --git a/Source/cmNinjaTargetGenerator.cxx 
b/Source/cmNinjaTargetGenerator.cxx
index e48ac12..034aefe 100644
--- a/Source/cmNinjaTargetGenerator.cxx
+++ b/Source/cmNinjaTargetGenerator.cxx
@@ -230,9 +230,13 @@ cmNinjaDeps cmNinjaTargetGenerator::ComputeLinkDeps() const
   if(!cli)
 return cmNinjaDeps();
 
-  const std::vectorstd::string deps = cli-GetDepends();
-  cmNinjaDeps result(deps.size());
-  std::transform(deps.begin(), deps.end(), result.begin(), MapToNinjaPath());
+  cmNinjaDeps result;
+  for(unsigned i = 0; i  cli-GetItems().size(); ++i) {
+if( cli-GetItems()[i].Target ) {
+  result.push_back( cli-GetItems()[i].Target-GetName() );
+}
+  }
+
   return result;
 }


Ninja was taken from https://github.com/syntheticpp/ninja.git, branch
token-splitter revision 335e08e.

I worked with some internal projects and with LLVM revision f340a29
taken from LLVM's official git mirror: http://llvm.org/git/llvm.git

First, some quick recap of the build tool I used so far with VS:

NMake: no support for parallel jobs.

MSBuild (equivalent to VS IDE): platform checks very slow, tricky
support for parallel jobs (one knob /m:JOBS at MSBuild.exe level and
another indepent one /MP at the compiler driver level; it's easy to end
with starved cores or with dozens of compile jobs competing for the
available cores.) On addition, CMake+MSBuild suffers from a nasty bug
that consists on not being able to use the regenerated project files
when CMake is invoked from within the build because some CMakeLists.txt
changed. There more issues with MSBuild when it is used as a
replacement of `make' but those described so far are enough to motivate
anyone to search for a better alternative.

Jom: no support for building more than one top-level target in
parallel. This was reported to the author time ago as a feature request
and was closed as wontfix.

Now, for the numbers.

Build LLVM with -DCMAKE_BUILD_TYPE=Release:

ninja -j 4: 6m55s
MSBuild (cmake --build .): 38m17s (*)
jom: 10m45s

(*): this very long time may be due to the lack of top-level
parallelization (no /m:JOBS was used for invoking msbuild.exe) and/or a
slower console when executing on VMWare for showing all the text output
that msbuild emits.

No-op build (best of two consecutive runs):

ninja -j 4: 0.4s
MSBuild: 11s
jom: 53s

`ninja -t clean' takes less than a second.

On an internal project here, a full build with ninja requires half the
time of jom/msbuild (35s vs 1m20s) while a no-op build is instantaneous
with ninja (0.1s) while reasonably fast with msbuild (2.3s) and
annoyingly slow with jom (8.5s). That project consists on a shared
library with ~30 cpp files plus 10 small (typically 1 cpp file) shared
libraries or executables that depends on the big shared library. On this
scenario, Ninja's correct handling of parallel jobs makes a lot of a
difference over jom and msbuild.

CMake + Ninja looks like a perfect match for people building with VC++
outside of the IDE.

-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2697-g12ab4af

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  12ab4af0b9422b67ea975a3579a7c93cabae3a6b (commit)
   via  7ec2ebdbcfcc90fca928ca79cb3b719177503d2d (commit)
   via  d36d29f1f079c58bf7d5993da442e4296c7f82a8 (commit)
  from  39f0585e97783fa86779ad0c2067700f013f4a24 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=12ab4af0b9422b67ea975a3579a7c93cabae3a6b
commit 12ab4af0b9422b67ea975a3579a7c93cabae3a6b
Merge: 39f0585 7ec2ebd
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 10:14:11 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 10:14:11 2012 -0500

Merge topic 'fix-typos-12975' into next

7ec2ebd fix the same typos as found by Debian in other places, too
d36d29f various typo and formatting fixes in manual pages (#12975)


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7ec2ebdbcfcc90fca928ca79cb3b719177503d2d
commit 7ec2ebdbcfcc90fca928ca79cb3b719177503d2d
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 16:13:34 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:13:34 2012 +0100

fix the same typos as found by Debian in other places, too

diff --git a/Modules/FindCUDA.cmake b/Modules/FindCUDA.cmake
index 4d91a92..9f8d575 100644
--- a/Modules/FindCUDA.cmake
+++ b/Modules/FindCUDA.cmake
@@ -906,7 +906,7 @@ macro(CUDA_WRAP_SRCS cuda_target format generated_files)
 message( FATAL_ERROR Invalid format flag passed to CUDA_WRAP_SRCS: 
'${format}'.  Use OBJ or PTX.)
   endif()
 
-  # Set up all the command line flags here, so that they can be overriden on a 
per target basis.
+  # Set up all the command line flags here, so that they can be overridden on 
a per target basis.
 
   set(nvcc_flags )
 
diff --git a/Modules/FindImageMagick.cmake b/Modules/FindImageMagick.cmake
index 75523f4..52d575b 100644
--- a/Modules/FindImageMagick.cmake
+++ b/Modules/FindImageMagick.cmake
@@ -169,7 +169,7 @@ FOREACH(component ${ImageMagick_FIND_COMPONENTS}
 LIST(APPEND ImageMagick_REQUIRED_VARS 
ImageMagick_${component}_EXECUTABLE)
   ENDIF(is_requested GREATER -1)
 ELSEIF(ImageMagick_${component}_EXECUTABLE)
-  # if no components were requested explicitely put all (default) 
executables
+  # if no components were requested explicitly put all (default) 
executables
   # in the list
   LIST(APPEND ImageMagick_DEFAULT_EXECUTABLES 
${ImageMagick_${component}_EXECUTABLE})
 ENDIF(ImageMagick_FIND_COMPONENTS)
diff --git a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt 
b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
index f76f0d9..ec09aa5 100644
--- a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
+++ b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
@@ -16,16 +16,16 @@ macro(do_find MODULE_NAME)
 endmacro(do_find)
 
 # It is only possible to use either Qt3 or Qt4 in one project.
-# Since FindQt will complain if both are found we explicitely
-# filter out this and FindQt3. FindKDE3 also depends on Qt3 and
+# Since FindQt will complain if both are found we explicitly request Qt4 here
+# and filter out FindQt3. FindKDE3 also depends on Qt3 and
 # is therefore also blocked
+set(DESIRED_QT_VERSION 4)
 set(NO_QT4_MODULES Qt3 KDE3)
 
 # These modules are named Find*.cmake, but are nothing that works in
 # find_package().
 set(NO_FIND_MODULES PackageHandleStandardArgs PackageMessage)
 
-set(DESIRED_QT_VERSION 4)
 foreach(FIND_MODULE ${FIND_MODULES})
 string(REGEX REPLACE .*/Find(.*)\\.cmake$ \\1 MODULE_NAME 
${FIND_MODULE})
 

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d36d29f1f079c58bf7d5993da442e4296c7f82a8
commit d36d29f1f079c58bf7d5993da442e4296c7f82a8
Author: Modestas Vainius mo...@debian.org
AuthorDate: Sat Feb 18 16:11:18 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:12:45 2012 +0100

various typo and formatting fixes in manual pages (#12975)

The patch fixes the following lintian warnings:

W: cmake-data: manpage-has-errors-from-man 
usr/share/man/man1/cmakemodules.1.gz 2728: warning: macro `..' not defined
I: cmake-data: spelling-error-in-manpage 
usr/share/man/man1/cmakemodules.1.gz overriden overridden
I: cmake-data: spelling-error-in-manpage 
usr/share/man/man1/cmakemodules.1.gz overriden overridden
I: cmake-data: spelling-error-in-manpage 
usr/share/man/man1/cmakemodules.1.gz explicitely explicitly
I: cmake-data: spelling-error-in-manpage 
usr/share/man/man1/cmakemodules.1.gz jave java
W: cmake-data: manpage-has-errors-from-man 
usr/share/man/man1/cmakeprops.1.gz 1040: warning [p 25, 

[Cmake-commits] CMake branch, next, updated. v2.8.7-2701-g946ea33

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  946ea3392e481dc1c20bafbce20af8f12e273f6b (commit)
   via  e7ea895e35c45db32d057fb208c28b34224affe3 (commit)
  from  57bcbdd4b7d1537653257f559fb847eae74d7a01 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=946ea3392e481dc1c20bafbce20af8f12e273f6b
commit 946ea3392e481dc1c20bafbce20af8f12e273f6b
Merge: 57bcbdd e7ea895
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 10:23:42 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 10:23:42 2012 -0500

Merge topic 'improve-findfreetype' into next

e7ea895 Revert AllFindModules test: be strict about FREETYPE and LibXslt 
version


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e7ea895e35c45db32d057fb208c28b34224affe3
commit e7ea895e35c45db32d057fb208c28b34224affe3
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 16:22:45 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:22:45 2012 +0100

Revert AllFindModules test: be strict about FREETYPE and LibXslt version

This reverts commit bb1ba19ed73ef1e5dce10c69adbf57daa83b683b.

This will go in through it's own branch to avoid collisions.

diff --git a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt 
b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
index 373470f..f76f0d9 100644
--- a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
+++ b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
@@ -48,8 +48,8 @@ endif (NOT QT4_FOUND)
 # If any of these modules reported that it was found a version number should 
have been
 # reported.
 set(VERSIONS_REQUIRED
-ALSA BISON BZIP2 CUPS CURL DOXYGEN EXPAT FLEX FREETYPE GETTEXT GIF GIT
-ImageMagick JASPER LibArchive LIBXML2 LIBXSLT PERL PostgreSQL SWIG TIFF 
ZLIB)
+ALSA BISON BZIP2 CUPS CURL DOXYGEN EXPAT FLEX GETTEXT GIF GIT
+ImageMagick JASPER LibArchive LIBXML2 PERL PostgreSQL SWIG TIFF ZLIB)
 
 foreach(VTEST ${VERSIONS_REQUIRED})
 if (${VTEST}_FOUND)

---

Summary of changes:
 Tests/CMakeOnly/AllFindModules/CMakeLists.txt |4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2703-gc984ff2

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  c984ff2728288c7a5f38aa323110f5e1845b91fe (commit)
   via  540db7e5b9bea875894ae5ed70499f1984b75e4d (commit)
  from  946ea3392e481dc1c20bafbce20af8f12e273f6b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c984ff2728288c7a5f38aa323110f5e1845b91fe
commit c984ff2728288c7a5f38aa323110f5e1845b91fe
Merge: 946ea33 540db7e
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 10:32:24 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 10:32:24 2012 -0500

Merge topic 'expect-more-versions' into next

540db7e AllFindModules test: expect more modules to have a version number 
available


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=540db7e5b9bea875894ae5ed70499f1984b75e4d
commit 540db7e5b9bea875894ae5ed70499f1984b75e4d
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Fri Feb 17 18:46:23 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:25:41 2012 +0100

AllFindModules test: expect more modules to have a version number available

For all current build machines the modules FindPkgConfig, FindFreetype, and
FindLibXslt return a version number. Enforce this to early catch when this
is not always the case.

diff --git a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt 
b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
index f76f0d9..7a8a575 100644
--- a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
+++ b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
@@ -48,8 +48,9 @@ endif (NOT QT4_FOUND)
 # If any of these modules reported that it was found a version number should 
have been
 # reported.
 set(VERSIONS_REQUIRED
-ALSA BISON BZIP2 CUPS CURL DOXYGEN EXPAT FLEX GETTEXT GIF GIT
-ImageMagick JASPER LibArchive LIBXML2 PERL PostgreSQL SWIG TIFF ZLIB)
+ALSA BISON BZIP2 CUPS CURL DOXYGEN EXPAT FLEX FREETYPE GETTEXT GIF GIT
+ImageMagick JASPER LibArchive LIBXML2 LIBXSLT PERL PKG_CONFIG PostgreSQL
+SWIG TIFF ZLIB)
 
 foreach(VTEST ${VERSIONS_REQUIRED})
 if (${VTEST}_FOUND)

---

Summary of changes:
 Tests/CMakeOnly/AllFindModules/CMakeLists.txt |5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2705-g1c74338

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  1c743388e414a33f73482e4e39861f13fe42a40d (commit)
   via  b4b349714739efc46de44fd9471cb36bdb4224f2 (commit)
  from  c984ff2728288c7a5f38aa323110f5e1845b91fe (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1c743388e414a33f73482e4e39861f13fe42a40d
commit 1c743388e414a33f73482e4e39861f13fe42a40d
Merge: c984ff2 b4b3497
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 10:52:32 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 10:52:32 2012 -0500

Merge topic 'improve-findopenmp' into next

b4b3497 FindOpenMP: add a default flag for PathScale compiler


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b4b349714739efc46de44fd9471cb36bdb4224f2
commit b4b349714739efc46de44fd9471cb36bdb4224f2
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 16:52:22 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:52:22 2012 +0100

FindOpenMP: add a default flag for PathScale compiler

diff --git a/Modules/FindOpenMP.cmake b/Modules/FindOpenMP.cmake
index ed5ef8f..e1af15e 100644
--- a/Modules/FindOpenMP.cmake
+++ b/Modules/FindOpenMP.cmake
@@ -40,7 +40,7 @@ function(_OPENMP_FLAG_CANDIDATES LANG)
 /openmp
 #Intel windows
 -Qopenmp
-#Intel
+#PathScale, Intel
 -openmp
 #Empty, if compiler automatically accepts openmp
  
@@ -50,22 +50,23 @@ function(_OPENMP_FLAG_CANDIDATES LANG)
 +Oopenmp
 #IBM XL C/c++
 -qsmp
-#Portland Group
+#Portland Group, MIPSpro
 -mp
   )
 
   set(OMP_FLAG_GNU -fopenmp)
-  set(OMP_FLAG_MSVC /openmp)
+  set(OMP_FLAG_HP +Oopenmp)
   if(WIN32)
 set(OMP_FLAG_Intel -Qopenmp)
   else()
 set(OMP_FLAG_Intel -openmp)
   endif()
-  set(OMP_FLAG_SunPro -xopenmp)
-  set(OMP_FLAG_HP +Oopenmp)
-  set(OMP_FLAG_XL -qsmp)
   set(OMP_FLAG_MIPSpro -mp)
+  set(OMP_FLAG_MSVC /openmp)
+  set(OMP_FLAG_PathScale -openmp)
   set(OMP_FLAG_PGI -mp)
+  set(OMP_FLAG_SunPro -xopenmp)
+  set(OMP_FLAG_XL -qsmp)
 
   # Move the flag that matches the compiler to the head of the list,
   # this is faster and doesn't clutter the output that much. If that

---

Summary of changes:
 Modules/FindOpenMP.cmake |   13 +++--
 1 files changed, 7 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2707-g704a6b0

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  704a6b00f36f8bfbafd05c074500d63768a13989 (commit)
   via  6f573ac9ee95cb7c05c8b37c9b192f4616747214 (commit)
  from  1c743388e414a33f73482e4e39861f13fe42a40d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=704a6b00f36f8bfbafd05c074500d63768a13989
commit 704a6b00f36f8bfbafd05c074500d63768a13989
Merge: 1c74338 6f573ac
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 10:53:03 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 10:53:03 2012 -0500

Merge topic 'improve-findopenmp' into next

6f573ac FindOpenMP: try the most likely flags first


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6f573ac9ee95cb7c05c8b37c9b192f4616747214
commit 6f573ac9ee95cb7c05c8b37c9b192f4616747214
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 8 19:23:38 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 16:52:50 2012 +0100

FindOpenMP: try the most likely flags first

Since we know which compiler we have we can test those OpenMP flags first 
that
are likely to be correct. This doesn't make any difference for GNU 
compilers,
but it should avoid useless try_compiles and output cluttering for all 
others.

diff --git a/Modules/FindOpenMP.cmake b/Modules/FindOpenMP.cmake
index ceac8d2..e1af15e 100644
--- a/Modules/FindOpenMP.cmake
+++ b/Modules/FindOpenMP.cmake
@@ -1,7 +1,7 @@
 # - Finds OpenMP support
 # This module can be used to detect OpenMP support in a compiler.
 # If the compiler supports OpenMP, the flags required to compile with
-# openmp support are set.  
+# openmp support are set.
 #
 # The following variables are set:
 #   OpenMP_C_FLAGS - flags to add to the C compiler for OpenMP support
@@ -13,6 +13,7 @@
 #=
 # Copyright 2009 Kitware, Inc.
 # Copyright 2008-2009 André Rigland Brodtkorb andre.brodtk...@ifi.uio.no
+# Copyright 2012 Rolf Eike Beer e...@sf-mail.de
 #
 # Distributed under the OSI-approved BSD License (the License);
 # see accompanying file Copyright.txt for details.
@@ -31,27 +32,52 @@ unset(_ENABLED_LANGUAGES)
 
 set(_OPENMP_REQUIRED_VARS)
 
-set(OpenMP_C_FLAG_CANDIDATES
-  #Gnu
-  -fopenmp
-  #Microsoft Visual Studio
-  /openmp
-  #Intel windows
-  -Qopenmp 
-  #Intel
-  -openmp 
-  #Empty, if compiler automatically accepts openmp
-   
-  #Sun
-  -xopenmp
-  #HP
-  +Oopenmp
-  #IBM XL C/c++
-  -qsmp
-  #Portland Group
-  -mp
-)
-set(OpenMP_CXX_FLAG_CANDIDATES ${OpenMP_C_FLAG_CANDIDATES})
+function(_OPENMP_FLAG_CANDIDATES LANG)
+  set(OpenMP_FLAG_CANDIDATES
+#GNU
+-fopenmp
+#Microsoft Visual Studio
+/openmp
+#Intel windows
+-Qopenmp
+#PathScale, Intel
+-openmp
+#Empty, if compiler automatically accepts openmp
+ 
+#Sun
+-xopenmp
+#HP
++Oopenmp
+#IBM XL C/c++
+-qsmp
+#Portland Group, MIPSpro
+-mp
+  )
+
+  set(OMP_FLAG_GNU -fopenmp)
+  set(OMP_FLAG_HP +Oopenmp)
+  if(WIN32)
+set(OMP_FLAG_Intel -Qopenmp)
+  else()
+set(OMP_FLAG_Intel -openmp)
+  endif()
+  set(OMP_FLAG_MIPSpro -mp)
+  set(OMP_FLAG_MSVC /openmp)
+  set(OMP_FLAG_PathScale -openmp)
+  set(OMP_FLAG_PGI -mp)
+  set(OMP_FLAG_SunPro -xopenmp)
+  set(OMP_FLAG_XL -qsmp)
+
+  # Move the flag that matches the compiler to the head of the list,
+  # this is faster and doesn't clutter the output that much. If that
+  # flag doesn't work we will still try all.
+  if(OMP_FLAG_${CMAKE_${LANG}_COMPILER_ID})
+list(REMOVE_ITEM OpenMP_FLAG_CANDIDATES 
${OMP_FLAG_${CMAKE_${LANG}_COMPILER_ID}})
+list(INSERT OpenMP_FLAG_CANDIDATES 0 
${OMP_FLAG_${CMAKE_${LANG}_COMPILER_ID}})
+  endif()
+
+  set(OpenMP_${LANG}_FLAG_CANDIDATES ${OpenMP_FLAG_CANDIDATES} PARENT_SCOPE)
+endfunction(_OPENMP_FLAG_CANDIDATES)
 
 # sample openmp source code to test
 set(OpenMP_C_TEST_SOURCE 
@@ -65,16 +91,17 @@ int main() {
 #endif
 }
 )
-# if these are set then do not try to find them again,
-# by avoiding any try_compiles for the flags
-if(DEFINED OpenMP_C_FLAGS AND DEFINED OpenMP_CXX_FLAGS)
-  set(OpenMP_C_FLAG_CANDIDATES)
-  set(OpenMP_CXX_FLAG_CANDIDATES)
-endif(DEFINED OpenMP_C_FLAGS AND DEFINED OpenMP_CXX_FLAGS)
 
 # check c compiler
 if(NOT _HAVE_LANGUAGE_C EQUAL -1)
-  include(CheckCSourceCompiles)
+  # if these are set then do not try to find them again,
+  # by avoiding any try_compiles for the flags
+  if(OpenMP_C_FLAGS)
+unset(OpenMP_C_FLAG_CANDIDATES)
+  else()
+_OPENMP_FLAG_CANDIDATES(C)
+include(CheckCSourceCompiles)
+  

[Cmake-commits] CMake branch, next, updated. v2.8.7-2709-g7339cab

2012-02-18 Thread Alexander Neundorf
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  7339cab0d39c5bcdceca220d4397b796a6fbab56 (commit)
   via  54e1f6f5a572e47c5598fd53e3b9eb0a66739def (commit)
  from  704a6b00f36f8bfbafd05c074500d63768a13989 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7339cab0d39c5bcdceca220d4397b796a6fbab56
commit 7339cab0d39c5bcdceca220d4397b796a6fbab56
Merge: 704a6b0 54e1f6f
Author: Alexander Neundorf neund...@kde.org
AuthorDate: Sat Feb 18 15:02:15 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 15:02:15 2012 -0500

Merge topic 'GenerateExportHeader_MinorFix' into next

54e1f6f GenerateExportHeader: use double quotes around _gcc_version


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=54e1f6f5a572e47c5598fd53e3b9eb0a66739def
commit 54e1f6f5a572e47c5598fd53e3b9eb0a66739def
Author: Alex Neundorf neund...@kde.org
AuthorDate: Sat Feb 18 20:58:19 2012 +0100
Commit: Alex Neundorf neund...@kde.org
CommitDate: Sat Feb 18 20:58:19 2012 +0100

GenerateExportHeader: use double quotes around _gcc_version

The GenerateExportHeaders test was failing on one machine, the version
could not be determined there, so the _gcc_version was empty,
so the first argument to if() was empty, so it complained:
http://open.cdash.org/testDetails.php?test=135623436build=2016288
Use double quotes to turn the non-existant first argument into an empty
string.

Alex

diff --git a/Modules/GenerateExportHeader.cmake 
b/Modules/GenerateExportHeader.cmake
index 781b6e7..f3f61f6 100644
--- a/Modules/GenerateExportHeader.cmake
+++ b/Modules/GenerateExportHeader.cmake
@@ -173,7 +173,7 @@ macro(_test_compiler_hidden_visibility)
 _gcc_version ${_gcc_version_info})
 endif()
 
-if(${_gcc_version} VERSION_LESS 4.2)
+if(${_gcc_version} VERSION_LESS 4.2)
   set(GCC_TOO_OLD TRUE)
   message(WARNING GCC version older than 4.2)
 endif()

---

Summary of changes:
 Modules/GenerateExportHeader.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2712-g48382d5

2012-02-18 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  48382d577d3bda377183c781096b595dc3f260ad (commit)
   via  b8a274c091b63e6203b61f5aee40393d1409c9fc (commit)
   via  a6bce55aefd332f148a2753d5be0ec4383534473 (commit)
  from  7339cab0d39c5bcdceca220d4397b796a6fbab56 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=48382d577d3bda377183c781096b595dc3f260ad
commit 48382d577d3bda377183c781096b595dc3f260ad
Merge: 7339cab b8a274c
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sat Feb 18 16:12:29 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 16:12:29 2012 -0500

Merge topic 'CPack-dynamicDocSection' into next

b8a274c Add structured documentation for NSIS
a6bce55 Dynamically add documentation section specified in documented 
script.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b8a274c091b63e6203b61f5aee40393d1409c9fc
commit b8a274c091b63e6203b61f5aee40393d1409c9fc
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sat Feb 18 22:10:19 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sat Feb 18 22:10:19 2012 +0100

Add structured documentation for NSIS

diff --git a/Modules/CPackNSIS.cmake b/Modules/CPackNSIS.cmake
index d9dab53..093d0fc 100644
--- a/Modules/CPackNSIS.cmake
+++ b/Modules/CPackNSIS.cmake
@@ -1,70 +1,112 @@
+##section Variables specific to CPack Debian (DEB) generator
+##end
+##module
 # - CPack NSIS generator specific options
 #
 # The following variables are specific to the graphical installers built
 # on Windows using the Nullsoft Installation System.
+##end
 #
+##variable
 #   CPACK_PACKAGE_INSTALL_REGISTRY_KEY - Registry key used when
 #   installing this project.
+##end
 #
+##variable
 #   CPACK_NSIS_INSTALL_ROOT - The default installation directory presented
 #   to the end user by the NSIS installer is under this root dir. The full
 #   directory presented to the end user is:
 #   ${CPACK_NSIS_INSTALL_ROOT}/${CPACK_PACKAGE_INSTALL_DIRECTORY}
+##end
 #
+##variable
 #   CPACK_NSIS_MUI_ICON - The icon file (.ico) for the generated
 #   install program.
+##end
 #
+##variable
 #   CPACK_NSIS_MUI_UNIICON - The icon file (.ico) for the generated
 #   uninstall program.
+##end
 #
+##variable
 #   CPACK_PACKAGE_ICON - A branding image that will be displayed inside
 #   the installer.
+##end
 #
+##variable
 #   CPACK_NSIS_EXTRA_INSTALL_COMMANDS - Extra NSIS commands that will
 #   be added to the install Section.
+##end
 #
+##variable
 #   CPACK_NSIS_EXTRA_UNINSTALL_COMMANDS - Extra NSIS commands that will
 #   be added to the uninstall Section.
+##end
 #
+##variable
 #   CPACK_NSIS_COMPRESSOR - The arguments that will be passed to the
 #   NSIS SetCompressor command.
+##end
 #
+##variable
 #   CPACK_NSIS_MODIFY_PATH - If this is set to ON, then an extra page
 #   will appear in the installer that will allow the user to choose
 #   whether the program directory should be added to the system PATH
 #   variable.
+##end
 #
+##variable
 #   CPACK_NSIS_DISPLAY_NAME - The display name string that appears in
 #   the Windows Add/Remove Program control panel
+##end
 #
+##variable
 #   CPACK_NSIS_PACKAGE_NAME - The title displayed at the top of the
 #   installer.
+##end
 #
+##variable
 #   CPACK_NSIS_INSTALLED_ICON_NAME - A path to the executable that
 #   contains the installer icon.
+##end
 #
+##variable
 #   CPACK_NSIS_HELP_LINK - URL to a web site providing assistance in
 #   installing your application.
+##end
 #
+##variable
 #   CPACK_NSIS_URL_INFO_ABOUT - URL to a web site providing more
 #   information about your application.
+##end
 #
+##variable
 #   CPACK_NSIS_CONTACT - Contact information for questions and comments
 #   about the installation process.
+##end
 #
+##variable
 #   CPACK_NSIS_CREATE_ICONS_EXTRA - Additional NSIS commands for
 #   creating start menu shortcuts.
+##end
 #
+##variable
 #   CPACK_NSIS_DELETE_ICONS_EXTRA -Additional NSIS commands to
 #   uninstall start menu shortcuts.
+##end
 #
+##variable
 #   CPACK_NSIS_EXECUTABLES_DIRECTORY - Creating NSIS start menu links
 #   assumes that they are in 'bin' unless this variable is set.
 #   For example, you would set this to 'exec' if your executables are
 #   in an exec directory.
+##end
 #
+##variable
 #   CPACK_NSIS_MUI_FINISHPAGE_RUN - Specify an executable to add an option
 #   to run on the finish page of the NSIS installer.
+##end
 
 #=
 # Copyright 2006-2009 Kitware, Inc.


[Cmake-commits] CMake branch, next, updated. v2.8.7-2717-g629cca4

2012-02-18 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  629cca4518cec1781bc9bbb3bd20ec0d74a62429 (commit)
   via  dee0a38648195786bae0abce437ef4617ea0912e (commit)
   via  b4abcfecbe281373fd3c28adccf4c3002b7909c4 (commit)
   via  9717727d5fa29a993b22b9437e67cc28d8eaf52c (commit)
   via  7a8f44a2d6d23ec0345a1413f3a79c21f9566456 (commit)
  from  48382d577d3bda377183c781096b595dc3f260ad (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=629cca4518cec1781bc9bbb3bd20ec0d74a62429
commit 629cca4518cec1781bc9bbb3bd20ec0d74a62429
Merge: 48382d5 dee0a38
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sat Feb 18 16:35:34 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 16:35:34 2012 -0500

Merge topic 'CPack-dynamicDocSection' into next

dee0a38 Put CPack DMG and PackageMaker doc in separate files
b4abcfe Correct copy/paste section name mistake
9717727 Suppress unecessary (now empty) doc sections
7a8f44a Add structure documentation for CPack Bundle generator


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dee0a38648195786bae0abce437ef4617ea0912e
commit dee0a38648195786bae0abce437ef4617ea0912e
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sat Feb 18 22:33:10 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sat Feb 18 22:33:10 2012 +0100

Put CPack DMG and PackageMaker doc in separate files

diff --git a/Modules/CPack.cmake b/Modules/CPack.cmake
index 8a44991..e0a5518 100644
--- a/Modules/CPack.cmake
+++ b/Modules/CPack.cmake
@@ -187,61 +187,6 @@
 #   list of patterns, e.g., /CVS/;/\\.svn/;\\.swp$;\\.#;/#;.*~;cscope.*
 ##end
 #
-# The following variables are specific to the DragNDrop installers
-# built on Mac OS X:
-#
-#   CPACK_DMG_VOLUME_NAME - The volume name of the generated disk
-#   image. Defaults to CPACK_PACKAGE_FILE_NAME.
-#
-#   CPACK_DMG_FORMAT - The disk image format. Common values are UDRO
-#   (UDIF read-only), UDZO (UDIF zlib-compressed) or UDBZ (UDIF
-#   bzip2-compressed). Refer to hdiutil(1) for more information on
-#   other available formats.
-#
-#   CPACK_DMG_DS_STORE - Path to a custom .DS_Store file which e.g.
-#   can be used to specify the Finder window position/geometry and
-#   layout (such as hidden toolbars, placement of the icons etc.).
-#   This file has to be generated by the Finder (either manually or
-#   through OSA-script) using a normal folder from which the .DS_Store
-#   file can then be extracted.
-#
-#   CPACK_DMG_BACKGROUND_IMAGE - Path to an image file which is to be
-#   used as the background for the Finder Window when the disk image
-#   is opened.  By default no background image is set. The background
-#   image is applied after applying the custom .DS_Store file.
-#
-#   CPACK_COMMAND_HDIUTIL - Path to the hdiutil(1) command used to
-#   operate on disk image files on Mac OS X. This variable can be used
-#   to override the automatically detected command (or specify its
-#   location if the auto-detection fails to find it.)
-#
-#   CPACK_COMMAND_SETFILE - Path to the SetFile(1) command used to set
-#   extended attributes on files and directories on Mac OS X. This
-#   variable can be used to override the automatically detected
-#   command (or specify its location if the auto-detection fails to
-#   find it.)
-#
-#   CPACK_COMMAND_REZ - Path to the Rez(1) command used to compile
-#   resources on Mac OS X. This variable can be used to override the
-#   automatically detected command (or specify its location if the
-#   auto-detection fails to find it.)
-#
-# The following variable is specific to installers build on Mac OS X
-# using PackageMaker:
-#
-#   CPACK_OSX_PACKAGE_VERSION - The version of Mac OS X that the
-#   resulting PackageMaker archive should be compatible
-#   with. Different versions of Mac OS X support different
-#   features. For example, CPack can only build component-based
-#   installers for Mac OS X 10.4 or newer, and can only build
-#   installers that download component son-the-fly for Mac OS X 10.5
-#   or newer. If left blank, this value will be set to the minimum
-#   version of Mac OS X that supports the requested features. Set this
-#   variable to some value (e.g., 10.4) only if you want to guarantee
-#   that your installer will work on that version of Mac OS X, and
-#   don't mind missing extra features available in the installer
-#   shipping with later versions of Mac OS X.
-#
 # The following variables are for advanced uses of CPack:
 #
 ##variable
diff --git a/Modules/CPackDMG.cmake b/Modules/CPackDMG.cmake
new 

[Cmake-commits] CMake branch, next, updated. v2.8.7-2719-ge175af3

2012-02-18 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  e175af3e74006e6f3a4fdaead20522b29034c45b (commit)
   via  cfac874b7783a5c464334bfc13d969a667f1c397 (commit)
  from  629cca4518cec1781bc9bbb3bd20ec0d74a62429 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e175af3e74006e6f3a4fdaead20522b29034c45b
commit e175af3e74006e6f3a4fdaead20522b29034c45b
Merge: 629cca4 cfac874
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sat Feb 18 17:12:41 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 17:12:41 2012 -0500

Merge topic 'CPack-dynamicDocSection' into next

cfac874 More documentation concerning CPack Components


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cfac874b7783a5c464334bfc13d969a667f1c397
commit cfac874b7783a5c464334bfc13d969a667f1c397
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sat Feb 18 23:10:14 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sat Feb 18 23:10:14 2012 +0100

More documentation concerning CPack Components

diff --git a/Modules/CPackComponent.cmake b/Modules/CPackComponent.cmake
index 016cb8c..1598703 100644
--- a/Modules/CPackComponent.cmake
+++ b/Modules/CPackComponent.cmake
@@ -1,4 +1,4 @@
-##section Variables common to all CPack generators
+##section Variables concerning CPack Components
 ##end
 ##module
 # - Build binary and source package installers
@@ -25,6 +25,51 @@
 # CPack commands:
 ##end
 #
+##variable
+#  CPACK_COMPONENTS_ALL - The list of component to install.
+#
+#  The default value of this variable is computed by CPack
+#  and contains all components defined by the project. The
+#  user may set it to only include the specified components.
+##end
+#
+##variable
+#  CPACK_GENNAME_COMPONENT_INSTALL - Enable/Disable component install for
+#  CPack generator GENNAME.
+#
+#  Each CPack Generator (RPM, DEB, ARCHIVE, NSIS, DMG, etc...) has a legacy
+#  default behavior. e.g. RPM builds monolithic whereas NSIS builds component.
+#  One can change the default behavior by setting this variable to 0/1 or 
OFF/ON.
+##end
+##variable
+#  CPACK_COMPONENTS_GROUPING - Specify how components are grouped for 
multi-package
+#  component-aware CPack generators.
+#
+#  Some generators like RPM or ARCHIVE family (TGZ, ZIP, ...) generates several
+#  packages files when asked for component packaging. They group the component
+#  differently depending on the value of this variable:
+# - ONE_PER_GROUP (default): creates one package file per component group
+# - ALL_COMPONENTS_IN_ONE : creates a single package with all (requested) 
component
+# - IGNORE : creates one package per component, i.e. IGNORE component group
+#  One can specify different grouping for different CPack generator by using
+#  a CPACK_PROJECT_CONFIG_FILE.
+##end
+##variable
+#  CPACK_COMPONENT_compName_DISPLAY_NAME - The name to be displayed for a 
component.
+##end
+##variable
+#  CPACK_COMPONENT_compName_DESCRIPTION - The description of a component.
+##end
+##variable
+#  CPACK_COMPONENT_compName_GROUP - The group of a component.
+##end
+##variable
+#  CPACK_COMPONENT_compName_DEPENDS - The dependencies (list of components)
+#  on which this component depends.
+##end
+##variable
+#  CPACK_COMPONENT_compName_REQUIRED - True is this component is required.
+##end
 ##macro
 #   cpack_add_component - Describes a CPack installation component
 #   named by the COMPONENT argument to a CMake INSTALL command.

---

Summary of changes:
 Modules/CPackComponent.cmake |   47 +-
 1 files changed, 46 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2723-g263d9bd

2012-02-18 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  263d9bdd64621370b1da991d7e3f0a3334643099 (commit)
   via  9a8103e929de7569fd2e5459a6676dff64d88892 (commit)
  from  b6012df7ad7145d35769aad98910cdd28c640302 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=263d9bdd64621370b1da991d7e3f0a3334643099
commit 263d9bdd64621370b1da991d7e3f0a3334643099
Merge: b6012df 9a8103e
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sat Feb 18 18:04:07 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 18:04:07 2012 -0500

Merge topic 'CPack-dynamicDocSection' into next

9a8103e Try to fix compile error on Win32-vs70


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9a8103e929de7569fd2e5459a6676dff64d88892
commit 9a8103e929de7569fd2e5459a6676dff64d88892
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sun Feb 19 00:01:39 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sun Feb 19 00:01:39 2012 +0100

Try to fix compile error on Win32-vs70

diff --git a/Source/cmDocumentation.cxx b/Source/cmDocumentation.cxx
index 1fb8ab6..904a157 100644
--- a/Source/cmDocumentation.cxx
+++ b/Source/cmDocumentation.cxx
@@ -16,6 +16,7 @@
 #include cmsys/Directory.hxx
 #include cmsys/Glob.hxx
 
+#include algorithm
 
 //
 static const char *cmDocumentationStandardOptions[][3] =
@@ -746,9 +747,9 @@ void cmDocumentation::addCPackStandardDocSections()
 void cmDocumentation::addAutomaticVariableSections(const std::string section)
 {
   std::vectorstd::string::iterator it;
-  it = find(this-VariableSections.begin(),
-this-VariableSections.end(),
-section);
+  it = std::find(this-VariableSections.begin(),
+ this-VariableSections.end(),
+ section);
   /* if the section does not exist then add it */
   if (it==this-VariableSections.end())
 {

---

Summary of changes:
 Source/cmDocumentation.cxx |7 ---
 1 files changed, 4 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-380-ge316cbb

2012-02-18 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  e316cbbbc32bd7711c4bbd96ab34adfa79722d79 (commit)
  from  bfbb57508603ab6c7007d75718b21868b690e151 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e316cbbbc32bd7711c4bbd96ab34adfa79722d79
commit e316cbbbc32bd7711c4bbd96ab34adfa79722d79
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Sun Feb 19 00:05:09 2012 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Sun Feb 19 00:05:09 2012 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index 2bf0e14..437a70f 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2012)
 SET(KWSYS_DATE_STAMP_MONTH 02)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   18)
+SET(KWSYS_DATE_STAMP_DAY   19)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] Build faild on Darwin? Don't know why?

2012-02-18 Thread Eric Noulard
My recent commit on CPack-dynamicDocSection
http://cmake.org/gitweb?p=cmake.git;a=shortlog;h=e175af3e74006e6f3a4fdaead20522b29034c45b

may have broken this build
http://open.cdash.org/testDetails.php?test=135708291build=2018382

the trouble is I cannot imagine why, since most of the modification where done
inside comment of some CPackXXX.cmake scripts.

The part of my commit located in C++ files should be unrelated to CPack Bundle
generator?

I'm not a Mac OS user  and the error:
CPack Error: Error executing: /Developer/Tools/SetFile -a C
/Volumes/BundleGeneratorTest-0.1-Darwin 1
CPack Error: Error assigning custom icon to temporary disk image.
CPack Error: Problem compressing the directory
CPack Error: Error when generating package: BundleGeneratorTest

does not give me much information.

Could someone help me with that, by may be

ctest -R BundleGeneratorTest on current next or stage/CPack-dynamicDocSection ?

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [CMake] Problems finding the SSL library

2012-02-18 Thread Matchek
2012/1/16 Michael Wild them...@gmail.com:
 Definitely a bug in MySQL. They should be setting
 CMAKE_REQUIRED_INCLUDES to ${OPENSSL_INCLUDE_DIR} before invoking the
 CHECK_SYMBOL_EXISTS() function/macro in line 72 of cmake/ssl.cmake.
 Otherwise CMake will not use the include directory found by
 FindOpenSSL.cmake.

It does the trick, thanks. This SSL problem was one of the most
frustrating experiences I ever had with any build system. It delayed
my Solaris build of MySQL 5.5 by at least three months. So thanks
again for helping me out!

Maciej
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Generating CMake scripts from Visual Studio solutions projects?

2012-02-18 Thread Andreas Mohr
Hi,

On Fri, Feb 17, 2012 at 12:00:10PM -0500, cmake-requ...@cmake.org wrote:
 Date: Fri, 17 Feb 2012 11:48:28 -0500
 From: John Drescher dresche...@gmail.com
 Subject: Re: [CMake] Generating CMake scripts from Visual Studio
   solutions  projects?
 To: Eric Noulard eric.noul...@gmail.com
 Cc: CMake ML cmake@cmake.org
 Message-ID:
   CAEhu1-56yW9fE5Xm-Bng+Y=wv+ig30wbcdv9dcuz2hgrity...@mail.gmail.com
 Content-Type: text/plain; charset=ISO-8859-1
 
  Did you try the tool listed in the Wiki
  http://www.cmake.org/Wiki/CMake#Visual_Studio
 
 
 I would be interested in if you get any of these to work well with non
 trivial projects. When I last looked at some of these (probably 2+
 years ago so things may have changed) they did not work well with my
 complex visual studio projects.

2+ years? That could easily end up like a Yugo vs. Porsche surprise ;)


The original vcproj2cmake script was composed of 300 lines,
and now the project is to the tune of around 4000 lines.

I've been doing more intensive updates in recent times,
carrying out parser - generator stages separation
and trying to get VS10 .vcxproj support finished real soonish.

For the (rather elaborate) needs of my largish build tree,
current .vcproj live conversion support is very adequate,
however there are still several weak or potentially even completely missing
areas left
(not to mention that differing requirements due to cross-platform extension
can easily mean that the base dataset itself as found in VS project files
is somewhat insufficient from the get go -
which my extensible hooks and mappings are supposed to be taking care of).
There's also a fair share of dark corners on CMake side as well, though
(include_directories() etc.), thus it's obvious that certain areas
of build systems often are considered to be less important.


Due to still very high development activity (i.e., many new features and
corrections arriving), at least for new users I'd _currently_ recommend
starting by directly checking out the experimental_unverified branch;
some longer-time users might need more stability and could thus
keep subscribing to experimental, whereas master currently is (too?) old.

If someone would like to create CMakeLists with it or use .vcproj
in their build, then simply ponder making use of the converter
(and possibly let me know of any issues or ideas that might turn up).

Thanks,

Andreas Mohr
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Generating CMake scripts from Visual Studio solutions projects?

2012-02-18 Thread John Drescher
 2+ years? That could easily end up like a Yugo vs. Porsche surprise ;)


 The original vcproj2cmake script was composed of 300 lines,
 and now the project is to the tune of around 4000 lines.


I have a lot of 5 to 15 year old MFC code(applications, dlls, static
libraries) that I would like to use this on. I could give it a test
sometime next week.

John
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] Cmake hangs on testing -- Check for working C compiler using: Visual Studio 10

2012-02-18 Thread Nicky Perian
This hang happened after installing Visual Studio 10 Service Pack 1.

Is there a known workaround for this?
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

Re: [CMake] Cmake hangs on testing -- Check for working C compiler using: Visual Studio 10

2012-02-18 Thread Nicky Perian
Mantis == 0011968: cmake uses wrong project-guid entry (Visual Studio
2010): ProjectGUID

This is marked minor. The solution is in deed minor. The steps to the
solution are anything but.

Find in Files ProjectGUID Replace ProjectGuid in
build-dir/CMakeFiles/*.*

Rerun your generator and the solutions is made.

Should be able to build your solution


On Sun, Feb 19, 2012 at 2:53 AM, Nicky Perian nickyper...@gmail.com wrote:

 This hang happened after installing Visual Studio 10 Service Pack 1.

 Is there a known workaround for this?



--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

Re: [CMake] Cmake hangs on testing -- Check for working C compiler using: Visual Studio 10

2012-02-18 Thread Nicky Perian
Now I don't know what is happening. This is no longer working. Back to
hanging up.

On Sun, Feb 19, 2012 at 7:59 AM, Nicky Perian nickyper...@gmail.com wrote:

 Mantis == 0011968: cmake uses wrong project-guid entry (Visual Studio
 2010): ProjectGUID

 This is marked minor. The solution is in deed minor. The steps to the
 solution are anything but.

 Find in Files ProjectGUID Replace ProjectGuid in
 build-dir/CMakeFiles/*.*

 Rerun your generator and the solutions is made.

 Should be able to build your solution



 On Sun, Feb 19, 2012 at 2:53 AM, Nicky Perian nickyper...@gmail.comwrote:

 This hang happened after installing Visual Studio 10 Service Pack 1.

 Is there a known workaround for this?




--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

Re: [CMake] Cmake hangs on testing -- Check for working C compiler using: Visual Studio 10

2012-02-18 Thread John Drescher
 Now I don't know what is happening. This is no longer working. Back to
 hanging up.


I have never had this hang and I use visual studio 2010 SP1 daily for
over a year with cmake. Now I am on cmake-2.8.7 however I have used
probably every other 2.8 release as well.

John
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Cmake hangs on testing -- Check for working C compiler using: Visual Studio 10

2012-02-18 Thread John Drescher
On Sat, Feb 18, 2012 at 11:23 PM, Nicky Perian nickyper...@gmail.com wrote:
 Applied 5 additional microsoft updates related to sp1 and seems to by
 working. Need to follow my own advice and apply updates to exhaustion.

I do have Microsoft Update running on all machines that I use CMake/VS
2010 and all of them are kept up to date.

John
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v2.8.7-2694-g39f0585

2012-02-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  39f0585e97783fa86779ad0c2067700f013f4a24 (commit)
   via  27501155c7bcc04ada498407ad3d6fd40dbea2bd (commit)
   via  bfbb57508603ab6c7007d75718b21868b690e151 (commit)
  from  f6b791bedefedf3fefb86bb7f893749a88715d5f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=39f0585e97783fa86779ad0c2067700f013f4a24
commit 39f0585e97783fa86779ad0c2067700f013f4a24
Merge: f6b791b 2750115
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 05:58:38 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Feb 18 05:58:38 2012 -0500

Merge topic 'improve-findpkgconfig' into next

2750115 FindPkgConfig: support version selection of pkg-config itself
bfbb575 KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=27501155c7bcc04ada498407ad3d6fd40dbea2bd
commit 27501155c7bcc04ada498407ad3d6fd40dbea2bd
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Sat Feb 18 11:57:38 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Sat Feb 18 11:57:38 2012 +0100

FindPkgConfig: support version selection of pkg-config itself

diff --git a/Modules/FindPkgConfig.cmake b/Modules/FindPkgConfig.cmake
index ce58899..5d93ab1 100644
--- a/Modules/FindPkgConfig.cmake
+++ b/Modules/FindPkgConfig.cmake
@@ -13,14 +13,17 @@
 # When the 'QUIET' argument is set, no status messages will be printed.
 #
 # It sets the following variables:
 #   PKG_CONFIG_FOUND ... true if pkg-config works on the system
 #   PKG_CONFIG_EXECUTABLE... pathname of the pkg-config program
 #   PREFIX_FOUND   ... set to 1 if module(s) exist
 #
 # For the following variables two sets of values exist; first one is the
 # common one and has the given PREFIX. The second set contains flags
 # which are given out when pkgconfig was called with the '--static'
 # option.
+#   XPREFIX_FOUND  ... set to 1 if module(s) exist
 #   XPREFIX_LIBRARIES  ... only the libraries (w/o the '-l')
 #   XPREFIX_LIBRARY_DIRS   ... the paths of the libraries (w/o the '-L')
 #   XPREFIX_LDFLAGS... all required linker flags
@@ -89,9 +92,17 @@ set(PKG_CONFIG_VERSION 1)
 find_program(PKG_CONFIG_EXECUTABLE NAMES pkg-config DOC pkg-config 
executable)
 mark_as_advanced(PKG_CONFIG_EXECUTABLE)
 
-include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-find_package_handle_standard_args(PkgConfig DEFAULT_MSG PKG_CONFIG_EXECUTABLE)
+if (PKG_CONFIG_EXECUTABLE)
+  execute_process(COMMAND ${PKG_CONFIG_EXECUTABLE} --version
+OUTPUT_VARIABLE PKG_CONFIG_VERSION_STRING
+ERROR_QUIET
+OUTPUT_STRIP_TRAILING_WHITESPACE)
+endif (PKG_CONFIG_EXECUTABLE)
 
+include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
+find_package_handle_standard_args(PkgConfig
+  REQUIRED_VARS PKG_CONFIG_EXECUTABLE
+  VERSION_VAR PKG_CONFIG_VERSION_STRING)
 
 # Unsets the given variables
 macro(_pkgconfig_unset var)

---

Summary of changes:
 Modules/FindPkgConfig.cmake   |   21 -
@@ -13,14 +13,17 @@
 #
 # It sets the following variables:
-#   PKG_CONFIG_FOUND ... true if pkg-config works on the system
-#   PKG_CONFIG_EXECUTABLE... pathname of the pkg-config program
-#   PREFIX_FOUND   ... set to 1 if module(s) exist
+#   PKG_CONFIG_FOUND  ... true if pkg-config works on the system
+#   PKG_CONFIG_EXECUTABLE ... pathname of the pkg-config program
+#   PKG_CONFIG_VERSION_STRING ... the version of the pkg-config program found
+# (since CMake 2.8.8)
+#   PKG_CONFIG_FOUND  ... if pkg-config executable was found
 #
 # For the following variables two sets of values exist; first one is the
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 2 files changed, 17 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits